﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Web;

namespace WisejWebApplication1
{
    public class SystemEvent : INotifyPropertyChanged
    {

        private int _eventID;
        private string _eventName;
        private DateTime _eventTime;
        private string _eventTimeString;
        private Color _eventColor;

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {

            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));

        }

        public SystemEvent(int id, string name)
        {

            _eventID = id;

            _eventName = name;

            _eventTime = DateTime.Now;

            _eventColor = Color.Green;

            CalculateTimes();

        }

        public SystemEvent() { }

        [System.ComponentModel.Browsable(false)]
        public int EventID
        {
            get => _eventID;
            set
            {
                _eventID = value;
                OnPropertyChanged();
            }
        }

        public string EventName
        {
            get => _eventName;
            set
            {
                _eventName = value;
                OnPropertyChanged();
            }
        }

        [System.ComponentModel.Browsable(false)]
        public DateTime EventTime
        {
            get => _eventTime;
            set
            {
                _eventTime = value;
                OnPropertyChanged();
            }
        }
        public string EventTimeString
        {
            get => _eventTimeString;
            set
            {
                _eventTimeString = value;
                OnPropertyChanged();
            }

        }

        [System.ComponentModel.Browsable(false)]
        public Color StatusColor
        {
            get => _eventColor;
            set
            {
                _eventColor = value;
            }
        }

        public string StatusColorString
        {
            get
            {
                return $"<div style='width:24px;height:24px;border-radius:100%;background-color:{ColorTranslator.ToHtml(this.StatusColor)}'></div>";
            }
        }

        public void CalculateTimes()
        {

            TimeSpan eventTime = DateTime.Now - _eventTime;

            EventTimeString = String.Format("{0:D2}:{1:D2}", eventTime.Minutes, eventTime.Seconds);

            //Couple of Dummy Color Changes
            if (eventTime.Seconds < 15) return;

            if (eventTime.Seconds >= 15 && eventTime.Seconds < 30)
            {
                StatusColor = Color.Yellow;
            }
            else if (eventTime.Seconds >= 30 && eventTime.Seconds < 45)
            {
                StatusColor = Color.Orange;
            }
            else
            {
                StatusColor = Color.Red;
            }

        }

    }
}